===========
TV Commands
===========

The available commands may vary by model and can be found by
`pyravia.BraviaTV.get_code_names`. However, the following are the codes found
on a XBR75X850D::

  ActionMenu
  Analog
  Analog2
  AnalogRgb1
  Assists
  Audio
  AudioMixDown
  AudioMixUp
  AudioQualityMode
  Blue
  BS
  BSCS
  ChannelDown
  ChannelUp
  ClosedCaption
  Component1
  Component2
  Confirm
  CS
  CursorDown
  CursorLeft
  CursorRight
  CursorUp
  Ddata
  DemoMode
  DemoSurround
  Digital
  DigitalToggle
  Display
  DOT
  Down
  DpadCenter
  DUX
  Enter
  EPG
  Exit
  FlashMinus
  FlashPlus
  FootballMode
  Forward
  GGuide
  Green
  Hdmi1
  Hdmi2
  Hdmi3
  Hdmi4
  Help
  Home
  iManual
  Input
  Jump
  Left
  Media
  MediaAudioTrack
  Mode3D
  Mute
  Netflix
  Next
  Num0
  Num1
  Num11
  Num12
  Num2
  Num3
  Num4
  Num5
  Num6
  Num7
  Num8
  Num9
  OneTouchTimeRec
  OneTouchView
  Options
  PAP
  Pause
  PhotoFrame
  PicOff
  PictureMode
  PictureOff
  Play
  PopUpMenu
  PowerOff
  Prev
  Rec
  Red
  Return
  Rewind
  Right
  ShopRemoteControlForcedDynamic
  Sleep
  SleepTimer
  Stop
  SubTitle
  SyncMenu
  Teletext
  TenKey
  TopMenu
  Tv
  TvAnalog
  TvAntennaCable
  TvInput
  TvPower
  Tv_Radio
  TvSatellite
  Up
  Video1
  Video2
  VolumeDown
  VolumeUp
  WakeUp
  Wide
  WirelessSubwoofer
  Yellow
